Wikin v1.0.3 - Documentation

Wikin v1.0.3

# Wikin

Documentation generated by Wikin.

## Module: wikin

Wikin - A simple and beautiful documentation generator for Python.

## Module: wikin.__main__

CLI entry point for Wikin.

### Functions

main function
`main()`

Main entry point for the Wikin CLI tool. Parses command line arguments and initiates documentation generation.

## Module: wikin.generator

Generator module for Wikin. Handles HTML generation from documentation data.

## Module: wikin.parser

Parser module for Wikin. Handles AST analysis of Python files.